
From: "Andi Kleen" <ak@suse.de>

Move memset_io out of line to avoid warnings.

Signed-off-by: Andi Kleen <ak@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/x86_64/lib/io.c    |    8 ++++++++
 25-akpm/include/asm-x86_64/io.h |    6 ++----
 2 files changed, 10 insertions(+), 4 deletions(-)

diff -puN arch/x86_64/lib/io.c~x86_64-move-memset_io-out-of-line-to-avoid-warnings arch/x86_64/lib/io.c
--- 25/arch/x86_64/lib/io.c~x86_64-move-memset_io-out-of-line-to-avoid-warnings	2005-01-09 23:01:26.225396240 -0800
+++ 25-akpm/arch/x86_64/lib/io.c	2005-01-09 23:01:26.230395480 -0800
@@ -13,3 +13,11 @@ void __memcpy_fromio(void *dst,unsigned 
 	__inline_memcpy(dst,(const void *) src,len);
 }
 EXPORT_SYMBOL(__memcpy_fromio);
+
+void memset_io(volatile void __iomem *a, int b, size_t c)
+{
+	/* XXX: memset can mangle the IO patterns quite a bit.
+	   perhaps it would be better to use a dumb one */
+	memset((void *)a,b,c);
+}
+EXPORT_SYMBOL(memset_io);
diff -puN include/asm-x86_64/io.h~x86_64-move-memset_io-out-of-line-to-avoid-warnings include/asm-x86_64/io.h
--- 25/include/asm-x86_64/io.h~x86_64-move-memset_io-out-of-line-to-avoid-warnings	2005-01-09 23:01:26.226396088 -0800
+++ 25-akpm/include/asm-x86_64/io.h	2005-01-09 23:01:26.231395328 -0800
@@ -260,10 +260,8 @@ static inline void memcpy_toio(volatile 
 {
 	__memcpy_toio((unsigned long)to,from,len);
 }
-static inline void memset_io(volatile void __iomem *a, int b, size_t c)
-{
-	memset((__force void *)a,b,c);
-}
+
+void memset_io(volatile void __iomem *a, int b, size_t c);
 
 /*
  * ISA space is 'always mapped' on a typical x86 system, no need to
_
